==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-mainmenu/translations/mainmenu_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="102"/>
        <source>Search...</source>
        <translation>ابحث…</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="110"/>
        <source>Show/hide main menu</source>
        <translation>اعرض/أخفِ القائمة الرئيسية</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>إعدادات القائمة الرئيسية</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>الأيقونة:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>نص الزرّ:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>حجم خط مخصّص:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translatorcomment>معدود!</translatorcomment>
        <translation> من النقاط</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>ملف القوائم</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>ملف القوائم:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>أقصى عرض للعنصر:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>اعرض المدخلات المتطابقة:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>أقصى عدد للعناصر الظاهرة:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>رشّح مدخلات القائمة</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>أخفِ مدخلات القائمة أثناء البحث</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>امسح البحث عند عرض القائمة</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>اختصار سطح المكتب</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>انقر الزرّ لتسجيل اختصار:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
        <source>Reset</source>
        <translation>صفّر</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
        <source>Choose icon file</source>
        <translation>اختر ملف أيقونة</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
        <source>Images (*.svg *.png)</source>
        <translation>الصور (‎*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
        <source>Choose menu file</source>
        <translation>اختر ملف القوائم</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
        <source>Menu files (*.menu)</source>
        <translation>ملفات القوائم (‎*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-mainmenu/translations/mainmenu_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="106"/>
        <source>Search...</source>
        <translation>ابحث…</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="114"/>
        <source>Show/hide main menu</source>
        <translation>اعرض/أخفِ القائمة الرئيسية</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="496"/>
        <source>Add to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="504"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="505"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="511"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="512"/>
        <source>The file cannot be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="518"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>إعدادات القائمة الرئيسية</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>الأيقونة:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>نص الزرّ:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>حجم خط مخصّص:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translatorcomment>معدود!</translatorcomment>
        <translation> من النقاط</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>ملف القوائم</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>ملف القوائم:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>أقصى عرض للعنصر:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>اعرض المدخلات المتطابقة:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>أقصى عدد للعناصر الظاهرة:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>رشّح مدخلات القائمة</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>أخفِ مدخلات القائمة أثناء البحث</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>امسح البحث عند عرض القائمة</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>اختصار سطح المكتب</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>انقر الزرّ لتسجيل اختصار:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
        <source>Reset</source>
        <translation>صفّر</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
        <source>Choose icon file</source>
        <translation>اختر ملف أيقونة</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
        <source>Images (*.svg *.png)</source>
        <translation>الصور (‎*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
        <source>Choose menu file</source>
        <translation>اختر ملف القوائم</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
        <source>Menu files (*.menu)</source>
        <translation>ملفات القوائم (‎*.menu)</translation>
    </message>
</context>
</TS>
